<?php

// $Id: admin.inc,v 1.7 2010/01/10 22:50:12 nickurbits Exp $

/**
 * Form for configuration options
 */
function licensing_form_admin_config() {
  $form = array(
    'licensing_secretkeyword' => array(
      '#title' => t('Secret keyword'),
      '#description' => t('This keyword is used as a part of the algorithm to create license keys. It is recommended to change it often to maintain the security of your licensing system, as this is a way to improve it\'s randomness.'),
      '#type' => 'textfield',
      '#default_value' => licensing_secretkeyword_get(FALSE),
      '#required' => TRUE,
    ),
    'licensing_license_branding' => array(
      '#title' => t('License key branding'),
      '#description' => t('You can put a string within the license keys generated on this site to brand them, similar to <em>XXXX-BRAND-XXXX-XXXX-XXXX</em>. This can be between 1 and 7 characters long.'),
      '#default_value' => strtoupper(variable_get('licensing_license_branding', LICENSING_LICENSE_BRANDING_DEFAULT)),
      '#type' => 'textfield',
      '#maxlength' => 7,
      '#size' => 8,
      '#required' => TRUE,
    ),
    'licensing_register_confirmation_enabled' => array(
      '#title' => t('Display confirmation message'),
      '#description' => t('Select the box to display a confirmation message after a successful license key registration. <small>It may be useful to disable this if another module displays more relevant information on registration.</small>'),
      '#type' => 'checkbox',
      '#default_value' => variable_get('licensing_register_confirmation_enabled', LICENSING_REGISTER_CONFIRMATION_ENABLED_DEFAULT),
    ),
    'user_register' => array(
      '#title' => t('User registration form'),
      '#description' => t('Settings related to the user registration form'),
      '#type' => 'fieldset',
      'licensing_user_register_enabled' => array(
        '#title' => t('Field enabled'),
        '#description' => t('Should the license key field be available on the user registration form?'),
        '#type' => 'checkbox',
        '#default_value' => variable_get('licensing_user_register_enabled', LICENSING_USER_REGISTER_ENABLED_DEFAULT),
      ),
      'licensing_user_register_mandatory' => array(
        '#title' => t('Mandatory'),
        '#description' => t('Should the license key field be required on the user registration form? (Requires the field to be enabled)'),
        '#type' => 'checkbox',
        '#default_value' => variable_get('licensing_user_register_mandatory', LICENSING_USER_REGISTER_MANDATORY_DEFAULT),
      ),
    ),
    'licensing_register' => array(
      '#type' => 'fieldset',
      '#title' => t('License registration page'),
      '#description' => t('Settings related to the license registration form'),
      'licensing_register_page_enabled' => array(
        '#title' => t('Enable'),
        '#description' => t('Check the box if the page should be enabled.'),
        '#type' => 'checkbox',
        '#default_value' => variable_get('licensing_register_page_enabled', LICENSING_REGISTER_PAGE_ENABLED_DEFAULT),
      ),
    ),
    '#submit' => array('licensing_form_admin_config_submit'),
  );
  return system_settings_form($form);
}

/**
 * Submit handler for licensing configuration form
 */
function licensing_form_admin_config_submit($form, $form_state) {
  if ($form_state['values']['licensing_register_page_enabled'] != variable_get('licensing_register_page_enabled', LICENSING_REGISTER_PAGE_ENABLED_DEFAULT)) {
    // a setting has been changed which changes a menu item. here we're telling
    // drupal that the menu tree needs to be rebuilt.
    variable_set('menu_rebuild_needed', TRUE);
  }
}